netapp_ontap.models.container_volume_s3_bucket_policy_statements API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.container_volume_s3_bucket_policy_statements`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ContainerVolumeS3BucketPolicyStatementsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ContainerVolumeS3BucketPolicyStatements object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `actions: List[str] GET POST PATCH`

    The actions field of the container_volume_s3_bucket_policy_statements.

    Example: ["GetObject","PutObject","DeleteObject","ListBucket"]

  `conditions: List[S3BucketPolicyCondition] GET POST PATCH`

    Specifies bucket policy conditions.

  `effect: str GET POST PATCH`

    Specifies whether access is allowed or denied when a user requests the specific action. If access (to allow) is not granted explicitly to a resource, access is implicitly denied. Access can also be denied explicitly to a resource, in order to make sure that a user cannot access it, even if a different policy grants access.

    Valid choices:

    - allow
    - deny
  `principals: List[str] GET POST PATCH`

    The principals field of the container_volume_s3_bucket_policy_statements.

    Example: ["user1","group/grp1","nasgroup/group1"]

  `resources: List[str] GET POST PATCH`

    The resources field of the container_volume_s3_bucket_policy_statements.

    Example: ["bucket1","bucket1/*"]

  `sid: str GET POST PATCH`

    Specifies the statement identifier used to differentiate between statements. The SID length can range from 1 to 256 characters.

    Example: Full_Access_To_User1!